@@ -41,14 +41,13 @@ class Freebox(IPlugin):
 		if entity == "Fb_Ch" :
 			on_off = "ONOFF"
 			location = "VIDE"
-		else entity == "Fb_info" :
+		if entity == "Fb_info" :
 			on_off = "ONOFF"
 		#	location = "VIDE"
-		else entity == "Fb_son" :
+		if entity == "Fb_son" :
 		#	on_off = "ONOFF"
 			location = "VIDE"
-		end if
-#
+		#
 		idex= entity + "_" + location + "_" + on_off
 		log.msg("index :  %s" % (idex))	
 #		
